package com.sky.ioc.service.meeting.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.sky.ioc.entity.domain.meeting.MeetingRecord;
import com.sky.ioc.entity.domain.meeting.MeetingRoom;
import com.sky.ioc.entity.params.IocParam;
import com.sky.ioc.mapper.job.TokenMapper;
import com.sky.ioc.mapper.meeting.MeetingRecordMapper;
import com.sky.ioc.service.meeting.MeetingRecordService;
import com.sky.ioc.tool.ReturnMsg;
import lombok.extern.slf4j.Slf4j;
import org.apache.el.parser.Token;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpMethod;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Service;
import org.springframework.web.client.RestTemplate;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import java.util.stream.Collectors;

@Service
@Slf4j
public class MeetingRecordServiceImpl implements MeetingRecordService {

    @Resource
    private MeetingRecordMapper meetingRecordMapper;

    @Autowired
    TokenMapper tokenMapper;

    final static  String MEETTING_RECORD_URL="http://192.168.1.45:9001/api/meeting/MEETING/record/list?pageNum=1&pageSize=1000";

    @Override
    public Map queryMeetingTreeList(IocParam iocParam) {
        LambdaQueryWrapper<MeetingRecord> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.ge(MeetingRecord::getStartTime, iocParam.getTimeRange().getStartDate());
        queryWrapper.le(MeetingRecord::getEndTime, iocParam.getTimeRange().getEndDate());
        List<MeetingRecord> meetingRecords = meetingRecordMapper.selectList(queryWrapper);
        Map collect = meetingRecords.stream().collect(Collectors.groupingBy(MeetingRecord::getFloor));
        for (Object key : collect.keySet()) {
            List<MeetingRecord> records = (List<MeetingRecord>) collect.get(key);
            Map<Integer, List<MeetingRecord>> map = records.stream().collect(Collectors.groupingBy(MeetingRecord::getRoomId));
            collect.put(key, map);
        }
        return collect;
    }

    @Override
    public List<MeetingRecord> queryMeetingList(IocParam iocParam) {
        LambdaQueryWrapper<MeetingRecord> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.ge(MeetingRecord::getStartTime, iocParam.getTimeRange().getStartDate());
        queryWrapper.le(MeetingRecord::getEndTime, iocParam.getTimeRange().getEndDate());
        List<MeetingRecord> meetingRecords = meetingRecordMapper.selectList(queryWrapper);
        return meetingRecords;
    }

    @Override
    public ReturnMsg getMeetingRecordList() {
        Map<String,String> tokenMap = tokenMapper.getNewToken();
        String token ="Bearer eyJhbGciOiJIUzUxMiJ9.eyJ1c2VyX2lkIjoxLCJ1c2VyX2tleSI6IjUwZTU1NTRkLWJjYzYtNGRhMS1iZDUxLWFhNTc3YzU4YTFiNCIsInVzZXJuYW1lIjoiYWRtaW4ifQ.X10VPYJfeeRTka7OtqNPOGMpL4QkW3fR_TfCKXCmO-yXbIIrr_40fcwiVnpXfYVENo_BvXWEACRd-Y6nXsbkog";
        if(tokenMap!=null){
            token = "Bearer "+tokenMap.get("token");
        }
        // 创建一个请求头对象
        HttpHeaders httpHeaders = new HttpHeaders();
        // 设置参数
        httpHeaders.set("authorization", token);
        // 创建一个响应体对象
        HttpEntity<String> httpEntity = new HttpEntity(httpHeaders);
        // 3.创建RestTemplate
        RestTemplate restTemplate = new RestTemplate();
        // 发送GET请求
        ResponseEntity<Map> responseEntity = restTemplate.exchange(MEETTING_RECORD_URL, HttpMethod.GET, httpEntity, Map.class);
        // 获取响应对象里的 body 对象
        Map<String, Object> body = responseEntity.getBody();
        // 获取状态码
        Integer code = (Integer)body.get("code");
        // 获取响应信息
        String message = (String)body.get("msg");
        if(code==200){
            ArrayList list = (ArrayList) body.get("rows");
            if(list!=null&&list.size()>0){
                meetingRecordMapper.delete(null);
                for (int i=0;i<list.size();i++){
                    LinkedHashMap json = (LinkedHashMap) list.get(i);
                    MeetingRecord meetingRecord = new MeetingRecord();
                    meetingRecord.setId((Integer) json.get("id"));
                    meetingRecord.setSubject((String) json.get("title"));
                    meetingRecord.setRoomId(Integer.parseInt(json.get("meetingRoomId").toString()));
                    String meetingDate = (String) json.get("meetingDate");
                    meetingRecord.setStartTime(meetingDate+" "+json.get("startTime"));
                    meetingRecord.setEndTime(meetingDate+" "+json.get("endTime"));
                    meetingRecord.setBookPerson((String) json.get("bookPerson"));
                    meetingRecord.setBookPhone((String) json.get("bookPhone"));
                    meetingRecordMapper.insert(meetingRecord);
                }
            }
            return ReturnMsg.ok();

        }else{
            log.info("获取会议记录数据："+message);
            return  ReturnMsg.fail(message);
        }

    }
}
